ApiDefinition class

Constructors

ApiDefinition({required String title, String? version, String? description, required List<ApiService> services, Map<String, String>? globalHeaders})
const

Properties

allEndpoints List<ApiEndpoint>
no setter
allTags List<String>
no setter
description String?
final
globalHeaders Map<String, String>?
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
services List<ApiService>
final
title String
final
version String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited