ApiDefinitionBuilder class

Constructors

ApiDefinitionBuilder()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bodyParam({Type dataType = Map, bool required = true, String? description}) ApiParameter
endpoint({required String name, required String path, required HttpMethod method, List<ApiParameter> parameters = const [], String? description, String? summary, List<String> tags = const [], Map<String, String>? headers, String? responseType}) ApiEndpoint
fieldParam(String name, {Type dataType = String, bool required = false, String? description, dynamic defaultValue}) ApiParameter
fromRetrofitService({required String serviceName, required String baseUrl, required List<ApiEndpoint> endpoints, String? description, Map<String, String>? defaultHeaders}) ApiDefinition
headerParam(String name, {Type dataType = String, bool required = false, String? description, dynamic defaultValue}) ApiParameter
pathParam(String name, {Type dataType = String, bool required = true, String? description}) ApiParameter
queryParam(String name, {Type dataType = String, bool required = false, String? description, dynamic defaultValue, List<String>? enumValues}) ApiParameter