ApiDefinitionsService class

Properties

definitions List<ApiDefinition>
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

addDefinition(ApiDefinition definition) → void
clearDefinitions() → void
getAllEndpoints() List<ApiEndpoint>
getEndpointsByTag(String tag) List<ApiEndpoint>
loadFromStorage() Future<void>
loadSampleDefinitions() → void
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeDefinition(ApiDefinition definition) → void
searchEndpoints(String query) List<ApiEndpoint>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

instance ApiDefinitionsService
no setter