ApiParameter class

Constructors

ApiParameter({required String name, required ParameterType type, required Type dataType, bool required = false, String? description, dynamic defaultValue, List<String>? enumValues})
const

Properties

dataType Type
final
defaultValue → dynamic
final
description String?
final
enumValues List<String>?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
required bool
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
type ParameterType
final
typeString String
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited