ApiService class

Constructors

ApiService({required String name, required String baseUrl, required List<ApiEndpoint> endpoints, String? description, List<String> tags = const [], Map<String, String>? defaultHeaders})
const

Properties

baseUrl String
final
defaultHeaders Map<String, String>?
final
description String?
final
endpoints List<ApiEndpoint>
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited