EndpointSpec class

Internal class to hold endpoint specification during building.

Constructors

EndpointSpec({required String name, required String path, required HttpMethod method, String? description, List<String> queryParams = const [], List<String> pathParams = const [], List<String> headerParams = const [], bool hasBody = false, List<String> tags = const [], String? responseType})

Properties

description String?
final
hasBody bool
final
hashCode int
The hash code for this object.
no setterinherited
headerParams List<String>
final
method HttpMethod
final
name String
final
path String
final
pathParams List<String>
final
queryParams List<String>
final
responseType String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tags List<String>
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited