HttpRequestRecord class

Constructors

HttpRequestRecord({required String id, required String method, required String url, required Map<String, dynamic> headers, dynamic body, required DateTime timestamp, HttpResponseRecord? response})
const

Properties

body → dynamic
final
hashCode int
The hash code for this object.
no setterinherited
headers Map<String, dynamic>
final
id String
final
method String
final
response HttpResponseRecord?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
timestamp DateTime
final
url String
final

Methods

copyWith({String? id, String? method, String? url, Map<String, dynamic>? headers, dynamic body, DateTime? timestamp, HttpResponseRecord? response}) HttpRequestRecord
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited