apiDefinitions property
Optional list of API definitions to display in the API tab.
If null or empty, only the History tab will be shown.
Implementation
final List<ApiDefinition>? apiDefinitions;
Optional list of API definitions to display in the API tab.
If null or empty, only the History tab will be shown.
final List<ApiDefinition>? apiDefinitions;