OpenApiLoader class

Loader for OpenAPI/Swagger specifications.

This class can load OpenAPI definitions from various sources and convert them to our internal API definition format.

Constructors

OpenApiLoader()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

fromAsset(String assetPath, {String? baseUrl}) Future<ApiDefinition?>
Loads an OpenAPI definition from an asset file.
fromJsonString(String jsonString, {String? baseUrl}) ApiDefinition?
Loads an OpenAPI definition from a JSON string.
fromMap(Map<String, dynamic> spec, {String? baseUrl}) ApiDefinition?
Loads an OpenAPI definition from a Map.
fromYamlString(String yamlString, {String? baseUrl}) ApiDefinition?
Loads an OpenAPI definition from a YAML string.