Summary class

Annotation to provide additional metadata for API endpoints.

This can be used alongside Retrofit annotations to provide more detailed information for the sandbox viewer.

Example:

@GET('/users/{id}')
@Summary('Get user by ID')
@Tags(['users', 'read'])
@ResponseType('User')
Future<User> getUser(@Path('id') int id);

Constructors

Summary(String value)
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
value String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited