ApiEndpoint class
Constructors
-
ApiEndpoint({required String name, required String path, required HttpMethod method, List<
ApiParameter> parameters = const [], String? description, String? summary, List<String> tags = const [], Map<String, String> ? headers, String? responseType}) -
const
Properties
- bodyParameter → ApiParameter?
-
no setter
- description → String?
-
final
-
fieldParameters
→ List<
ApiParameter> -
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headerParameters
→ List<
ApiParameter> -
no setter
-
headers
→ Map<
String, String> ? -
final
- method → HttpMethod
-
final
- methodString → String
-
no setter
- name → String
-
final
-
parameters
→ List<
ApiParameter> -
final
- path → String
-
final
-
pathParameters
→ List<
ApiParameter> -
no setter
-
queryParameters
→ List<
ApiParameter> -
no setter
- responseType → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- summary → String?
-
final
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited