RetrofitInspector class
Inspector that analyzes Retrofit service classes to extract API definitions.
This class uses static analysis of generated Retrofit code to automatically create API definitions without requiring additional annotations or code generation. It inspects the source files and generated code to extract endpoint information.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromService(
dynamic service, {required String baseUrl, String? title, String? description}) → Future< ApiDefinition?> - Extracts API definitions from a Retrofit service instance.
-
fromServices(
Map< dynamic, String> services) → Future<List< ApiDefinition> > - Extracts API definitions from multiple Retrofit services.